@@ -1,9 +1,9 @@
 #!/bin/sh -e
 
-libtoolize -f -c
+glibtoolize -f -c
 aclocal --force
 autoheader -f
 autoconf -f
-cp -f $(dirname $(which automake))/../share/automake/mkinstalldirs ./
+#cp -f $(dirname $(which automake))/../share/automake/mkinstalldirs ./
 cp -f $(dirname $(which automake))/../share/gettext/config.rpath ./
 automake -a -c --gnu --foreign
