@@ -6,6 +6,9 @@
 #include "eggtrayicon.h"
 #include "gimmix-tooltip.h"
 #include "sexy-tooltip.h"
+#ifdef HAVE_COVER_PLUGIN
+#	include	"gimmix-covers.h"
+#endif
 
 /* create system tray icon */
 void gimmix_create_systray_icon (void);
@@ -17,9 +20,12 @@ void gimmix_disable_systray_icon (void);
 void gimmix_enable_systray_icon (void);
 
 /* update notification tooltip */
-void gimmix_update_systray_tooltip (SongInfo *s);
+void gimmix_update_systray_tooltip (mpd_Song *s);
 
 /* destroy system tray icon */
 void gimmix_destroy_systray_icon (void);
 
+/* set default image of systray tooltip */
+void gimmix_systray_tooltip_set_default_image (void);
+
 #endif
